@@ -1,4 +1,4 @@
-library(precrec)
+#' @importFrom precrec
 
 context("AP 1: Autoplot for pipeline functions")
 # Test autoplot(object, ...)
